"use strict";

const mappedTypeName = require('./mapped-type-name');

const createMdxNode = (props, options) => {
  const {
    node,
    createContentDigest,
    actions,
    getNode,
    createNodeId
  } = props;
  const {
    createNode,
    createParentChildLink
  } = actions;
  const {
    types = {},
    basePath = '/'
  } = options; // Make sure it's an MDX node

  if (node.internal.type !== `Mdx`) {
    return;
  } // Create source field (according to contentPath)


  const fileNode = node.parent && getNode(node.parent);
  if (!fileNode) return;

  if (Boolean(types[fileNode.sourceInstanceName])) {
    const typeObj = types[fileNode.sourceInstanceName];
    const typeName = mappedTypeName(types)(fileNode.sourceInstanceName);
    const slug = `${typeObj.contentPath || typeName.toLowerCase()}/${fileNode.name}`;
    const newNode = {
      id: createNodeId(`${node.id} >>> ${typeName}`),
      children: [],
      parent: node.id,
      internal: {
        type: `${typeName}`
      },
      name: `${fileNode.name}`,
      slug,
      rawBody: node.rawBody,
      frontmatter: node.frontmatter,
      fileAbsolutePath: node.fileAbsolutePath
    };
    newNode.internal.contentDigest = createContentDigest(newNode);
    createNode(newNode);
    createParentChildLink({
      parent: node,
      child: newNode
    });
    return newNode;
  }
};

module.exports = createMdxNode;